# Speeshare
Easy way to share files in Python.
SpeeShare Python Module - Share-Online API.

<!-- PROJECT LOGO -->
<br />
<p align="center">
  <a>
    <img src="https://cdn.discordapp.com/attachments/996131130212352071/1074568653439250472/c8c34ebc5c2844b9.gif" alt="Logo" width="80" height="80">
  </a>

  <h3 align="center">Speeshare</h3>

  <p align="center">
    <samp>A free </samp><a href="https://fadcomp.tk"><strong>Speeshare</strong></a><samp> from </samp><a href="https://fadcomp.tk"><strong>Fander Company</strong></a>
    <br />
    <a href="https://github.com/Fander-Company/speeshare/issues/1">Comments</a>
    ·
    <a href="https://github.com/Fander-Company/speeshare/issues">Bug report</a>
    ·
    <a href="https://github.com/Fander-Company/speeshare/issues">Feature request</a>
  </p>
</p>

<br/>

### Techstack

* [Requests](https://requests.readthedocs.io/) - Module

<br/>

### Example to use

Install package.

```pip install speeshare```


Import package

```import speeshare as sp```


Simple method <strong>LOAD</strong>

```sp.load("fr.txt")```

### Support

If you use my project you can donate.

<a href="https://www.donationalerts.com/r/fander_company"><img src="https://res.cloudinary.com/dlqffpomw/image/upload/v1658231652/%D0%94%D0%B8%D0%B7%D0%B0%D0%B9%D0%BD_%D0%B1%D0%B5%D0%B7_%D0%BD%D0%B0%D0%B7%D0%B2%D0%B0%D0%BD%D0%B8%D1%8F_20_zf9rbw.png" height="35px"/></a>

<br/>

<!-- LICENSE -->
### Author

[Fander Company](https://fadcomp.tk)
